import { defineNuxtModule, createResolver, addPlugin, addServerHandler } from '@nuxt/kit';
import defu from 'defu';
import { fileURLToPath } from 'node:url';

var PageViewsProvider = /* @__PURE__ */ ((PageViewsProvider2) => {
  PageViewsProvider2["GoogleAnalytics"] = "googleAnalytics";
  return PageViewsProvider2;
})(PageViewsProvider || {});
const module = defineNuxtModule({
  meta: {
    name: "nuxt-pageviews",
    configKey: "pageViews"
  },
  defaults: {
    propertyId: "5555555",
    endpoint: "/api/views",
    exact: false,
    preload: true,
    startDate: "2018-01-01",
    provider: "googleAnalytics" /* GoogleAnalytics */,
    cacheTimeout: 60 * 30
  },
  setup(options, nuxt) {
    const { resolve } = createResolver(import.meta.url);
    const runtimeDir = fileURLToPath(new URL("./runtime", import.meta.url));
    nuxt.options.runtimeConfig.pageViews = defu(nuxt.options.runtimeConfig.pageViews, options);
    nuxt.options.runtimeConfig.public.pageViews = { endpoint: options.endpoint, exact: options.exact };
    nuxt.options.build.transpile.push(runtimeDir);
    const endpoint = options.endpoint;
    if (!endpoint) {
      console.warn("You must set a pageViews.endpoint in runtimeConfig.public!");
    }
    const pluginPath = resolve("./runtime/plugin");
    addPlugin(pluginPath);
    addServerHandler({
      route: endpoint,
      method: "get",
      handler: resolve(runtimeDir, "server/api/views.get")
    });
    nuxt.hook("imports:dirs", (dirs) => {
      dirs.push(resolve(runtimeDir, "composables"));
    });
    nuxt.hook("prepare:types", (options2) => {
      options2.references.push({ path: resolve(nuxt.options.buildDir, "types/pageviews.d.ts") });
    });
  }
});

export { PageViewsProvider, module as default };
