import { appendHeader, defineEventHandler, defineLazyEventHandler, getQuery } from "h3";
import { useRuntimeConfig } from "#imports";
import { googleAnalytics } from "../../adapters/GoogleAnalytics.mjs";
import { createStorage } from "unstorage";
import memoryDriver from "unstorage/drivers/memory";
export default defineLazyEventHandler(async () => {
  const config = await useRuntimeConfig();
  const storage = await createStorage({ driver: memoryDriver() });
  await storage.setItem("cache:pageViewsCacheRefresh", false);
  await storage.setItem("cache:pageViewsCacheProcessing", false);
  const providers = {
    "googleAnalytics": googleAnalytics
  };
  const provider = config.pageViews.provider;
  const refreshAnalyticsCache = async () => {
    let analyticsCache = await storage.getItemRaw("cache:pageViews");
    const analyticsCacheProcessing = await storage.getItem("cache:pageViewsCacheProcessing");
    const analyticsCacheRefresh = await storage.getItem("cache:pageViewsCacheRefresh");
    const shouldRefresh = !analyticsCacheProcessing && (analyticsCache === null || analyticsCacheRefresh);
    if (shouldRefresh) {
      const providerFunction = providers[provider];
      await storage.setItem("cache:pageViewsCacheRefresh", false);
      await storage.setItem("cache:pageViewsCacheProcessing", true);
      if (analyticsCache === null) {
        analyticsCache = await providerFunction(config, storage);
        await storage.setItemRaw("cache:pageViews", analyticsCache);
        await storage.setItem("cache:pageViewsCacheProcessing", false);
      } else {
        providerFunction(config, storage).then(async (analyticsCache2) => {
          await storage.setItemRaw("cache:pageViews", analyticsCache2);
          await storage.setItem("cache:pageViewsCacheRefresh", false);
        });
      }
      setTimeout(async () => {
        if (config.pageViews.debug)
          console.log("pageViews:timeout:needRefresh");
        await storage.setItem("cache:pageViewsCacheRefresh", true);
      }, config.pageViews.cacheTimeout * 1e3);
    }
    return analyticsCache;
  };
  if (config.pageViews.preload) {
    if (config.pageViews.debug)
      console.log("pageViews:preload");
    await refreshAnalyticsCache();
  }
  return defineEventHandler(async (event) => {
    if (config.pageViews.debug)
      console.time("pageViews:endpoint:handler");
    const query = getQuery(event);
    let path = query.path;
    if (!config.exact && path != "/") {
      path = path.replace(/\/$/, "");
    }
    const analyticsCache = refreshAnalyticsCache();
    if (config.pageViews.debug)
      console.timeEnd("pageViews:endpoint:handler");
    appendHeader(event, "Access-Control-Allow-Origin", "*");
    appendHeader(event, "Content-Type", "application/json");
    if (analyticsCache != null) {
      if (path === "*") {
        return analyticsCache;
      } else if (path in analyticsCache) {
        return { views: parseInt(analyticsCache[path]) };
      }
    }
    return { views: 0, empty: true };
  });
});
